require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module AllFromOrganizationalUnitCast
      # @deprecated All From OU will not be used in the new authorization (v4).
      class AllFromOrganizationalUnitCastAttributes < UU::OS::REST::DTO

        # UESURI of the organizational unit from which the group All From Organizational Unit
        # is derived to which the casted subject is casted.
        attr_accessor :organizational_unit_uri

        # UESURI of the subject (role or group) which is casted to the group
        # All From Organizational Unit.
        attr_accessor :casted_subject_uri

        # The level of the cast relation.
        #
        # @see UU::OS::Cast::CastLevel
        attr_accessor :level

        # Creation time of the cast.
        attr_accessor :date_from

        # The informative field describing the date when the cast should expire.
        attr_accessor :date_to

        # Specifies the state of the cast.
        #
        # @see UU::OS::Cast::CastState
        attr_accessor :state

        # Name of the organizational unit from which the group All From Organizational Unit
        # is derived to which the casted subject is casted.
        attr_accessor :organizational_unit_name

        # Code of the organizational unit from which the group All From Organizational Unit
        # is derived to which the casted subject is casted.
        attr_accessor :organizational_unit_code

        # Entity type URI of organizational unit.
        attr_accessor :organizational_unit_entity_type_uri

        # Name of the subject (role or group) which is casted to the group
        # All From Organizational Unit.
        attr_accessor :casted_subject_name

        # Code of the subject (role or group) which is casted to the group
        # All From Organizational Unit.
        attr_accessor :casted_subject_code

        # Entity type URI of casted subject.
        attr_accessor :casted_subject_entity_type_uri

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def casted_subject_uri
          attributes[:castedSubjectUri]
        end

        def casted_subject_uri=(val)
          if val
            attributes[:castedSubjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:castedSubjectUri] = nil
          end
        end

        def level
          attributes[:level]
        end

        def level=(val)
          attributes[:level] = val
        end

        def date_from
          attributes[:dateFrom]
        end

        def date_from=(val)
          attributes[:dateFrom] = val
        end

        def date_to
          attributes[:dateTo]
        end

        def date_to=(val)
          attributes[:dateTo] = val
        end

        def state
          attributes[:state]
        end

        def state=(val)
          attributes[:state] = val
        end

        def organizational_unit_name
          attributes[:organizationalUnitName]
        end

        def organizational_unit_name=(val)
          attributes[:organizationalUnitName] = val
        end

        def organizational_unit_code
          attributes[:organizationalUnitCode]
        end

        def organizational_unit_code=(val)
          attributes[:organizationalUnitCode] = val
        end

        def casted_subject_name
          attributes[:castedSubjectName]
        end

        def casted_subject_name=(val)
          attributes[:castedSubjectName] = val
        end

        def casted_subject_code
          attributes[:castedSubjectCode]
        end

        def casted_subject_code=(val)
          attributes[:castedSubjectCode] = val
        end

        def casted_subject_entity_type_uri
          attributes[:castedSubjectEntityTypeUri]
        end

        def casted_subject_entity_type_uri=(val)
          if val
            attributes[:castedSubjectEntityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:castedSubjectEntityTypeUri] = nil
          end
        end

        def organizational_unit_entity_type_uri
          attributes[:organizationalUnitEntityTypeUri]
        end

        def organizational_unit_entity_type_uri=(val)
          if val
            attributes[:organizationalUnitEntityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitEntityTypeUri] = nil
          end
        end

      end
    end

  end

end
