require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Artifact
      # Attributes of the artifact presentation setting.
      class ArtifactPresentationAttributes < UU::OS::REST::DTO
        # Normalized UESURI referencing the artifact. Never nil.
        attr_accessor :artifact_uri

        # Normalized UESURI referencing the layout artifact.
        attr_accessor :layout_artifact_uri

        # Width of the artifact. Never nil. Possible values see in {UU::OS::Artifact::ArtifactWidthType}.
        attr_accessor :artifact_width

        # Header type. Never nil. Possible values see in {UU::OS::Artifact::ArtifactHeaderDisplayMode}.
        attr_accessor :header_display_mode

        # Show/hide control bar. Never nil. Possible values see in {UU::OS::Artifact::ArtifactControlBarDisplayMode}.
        attr_accessor :control_bar_display_mode

        # Show/hide comments. Never nil. Possible values see in {UU::OS::Artifact::ArtifactCommentsDisplayMode}.
        attr_accessor :comment_display_mode

        # @deprecated Use {#artifact_display_mode artifact_display_mode} instead.
        attr_accessor :context_menu_display_mode

        # Show simple or advanced context menu. Never nil. Possible values see in {UU::OS::Artifact::ArtifactDisplayMode}.
        attr_accessor :artifact_display_mode

        # Represents visual style. Possible values see in {UU::OS::Artifact::ArtifactVisualStyle}.
        attr_accessor :visual_style

        # Show/hide navigation area when displaying sheet content. 
        # Navigation area contains navigation bar, header, heading and control bar. Possible values see in {UU::OS::Artifact::ArtifactNavigationAreaDisplayMode}.
        attr_accessor :navigation_area_display_mode

        def artifact_uri
          attributes[:artifactUri]
        end

        def artifact_uri=(val)
          if val
            attributes[:artifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:artifactUri] = nil
          end
        end

        def layout_artifact_uri
          attributes[:layoutArtifactUri]
        end

        def layout_artifact_uri=(val)
          if val
            attributes[:layoutArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:layoutArtifactUri] = nil
          end
        end

        def artifact_width
          attributes[:artifactWidth]
        end

        def  artifact_width=(val)
          attributes[:artifactWidth] = val
        end

        def header_display_mode
          attributes[:headerDisplayMode]
        end

        def header_display_mode=(val)
          attributes[:headerDisplayMode] = val
        end

        def control_bar_display_mode
          attributes[:controlBarDisplayMode]
        end

        def control_bar_display_mode=(val)
          attributes[:controlBarDisplayMode] = val
        end

        def comment_display_mode
          attributes[:commentDisplayMode]
        end

        def comment_display_mode=(val)
          attributes[:commentDisplayMode] = val
        end

        # @deprecated
        def context_menu_display_mode
          attributes[:contextMenuDisplayMode]
        end

        # @deprecated
        def context_menu_display_mode=(val)
          attributes[:contextMenuDisplayMode] = val
        end

        def artifact_display_mode
          attributes[:artifactDisplayMode]
        end

        def artifact_display_mode=(val)
          attributes[:artifactDisplayMode] = val
        end

        def visual_style
          attributes[:visualStyle]
        end

        def visual_style=(val)
          attributes[:visualStyle] = val
        end

        def navigation_area_display_mode
          attributes[:navigationAreaDisplayMode]
        end

        def navigation_area_display_mode=(val)
          attributes[:navigationAreaDisplayMode] = val
        end

      end
    end
  end
end
