require 'uu/os/rest/dto'
require 'uu/os/uesuri'


module UU
  module OS

    module Friend
      class FriendAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the friend. Never nil.
        attr_accessor :uri

        # First name of the friend. Never nil.
        attr_accessor :first_name

        # Surname of the friend. Never nil.
        attr_accessor :surname

        # Code of the friend. Never nil.
        attr_accessor :code

        # Description of the friend. Never nil.
        attr_accessor :description

        # URI of the friend's container. Never nil.
        attr_accessor :location_uri

        # URI of the organizational unit in which the friend role lies. Never nil.
        attr_accessor :organizational_unit_uri

        # URI of the meta artifact. Never nil.
        attr_accessor :meta_artifact_uri

        # Universe identifier of the personal role (user). Never nil.
        attr_accessor :universe_id

        # URI of the competent role. Never nil.
        attr_accessor :competent_role_uri

        # Security level of the friend. Never nil.
        #
        # @see UU::OS::Artifact::SecurityLevel
        attr_accessor :security_level

        # Creation stamp of the friend.
        attr_accessor :creation_stamp

        # Creation time of the friend.
        attr_accessor :creation_time

        # Modification stamp of the friend.
        attr_accessor :modification_stamp

        # Modification time of the friend.
        attr_accessor :modification_time

        # Version of the friend.
        attr_accessor :version

        # URI of the friend's icon. If nil is set, the friend uses icon from meta artifact.
        attr_accessor :icon_uri

        # @deprecated Always returns nil.
        attr_accessor :artifact_type

        # @deprecated Always returns nil.
        def artifact_type
          nil
        end

        # @deprecated Input value is ignored, nil is always assumed.
        def artifact_type=(val)
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def first_name
          attributes[:firstName]
        end

        def first_name=(val)
          attributes[:firstName] = val
        end

        def surname
          attributes[:surname]
        end

        def surname=(val)
          attributes[:surname] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def universe_id
          attributes[:universeId]
        end

        def universe_id=(val)
          attributes[:universeId] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        # @deprecated Use {FriendAttributes#version} instead.
        def revision 
          attributes[:version]
        end

        # @deprecated Use {FriendAttributes#version} instead.
        def revision=(val) 
          attributes[:version] = val
        end

        def version 
          attributes[:version]
        end

        def version=(val) 
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

      end
    end

  end
end
