require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module SheetTemplate
      class SheetTemplateAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the sheet template.
        attr_accessor :uri

        # Name of the sheet template.
        attr_accessor :name

        # Code of the sheet template.
        attr_accessor :code

        # UESURI of the sheet template from which the specified sheet template was copied.
        attr_accessor :source_template_uri

        # Order of sheet template on meta-artifact.
        attr_accessor :order

        # Flag of main sheet template.
        attr_accessor :main

        # Description of the sheet template.
        attr_accessor :description        

        # Specifies if the sheet template is locked.
        attr_accessor :locked

        # When the sheet template has been locked. Null if it is unlocked.
        attr_accessor :lock_time

        # What role has locked the sheet template. Null if it is unlocked.
        attr_accessor :lock_role_uri

        # Who (which access role) has locked the sheet template. Null if it is unlocked.
        attr_accessor :lock_access_role_uri

        # Flag of visible sheet template.
        attr_accessor :visible

        # Width of the sheet template.
        attr_accessor :width

        # Creattion time of the sheet template.
        attr_accessor :creation_time

        # Modification time of the sheet template.
        attr_accessor :modification_time
        
        # Creation stamp of the sheet template.
        attr_accessor :creation_stamp
        
        # Modification stamp of the sheet template.
        attr_accessor :modification_stamp
        
        # Version of the sheet template.
        attr_accessor :version
        
        # Version of the sheet.
        attr_accessor :version_label
        
        # UXML version of the sheet template.
        attr_accessor :uxml_version
        
        # Specifies whether sheet should be created by the sheet template simultaneously with artifact creation.
        attr_accessor :implicit_creation
        
        # UESURI of the entity type of the sheet template. Never nil.
        attr_accessor :entity_type_uri
        
        def uri 
          attributes[:uri]
        end

        def uri=(val) 
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name 
          attributes[:name]
        end

        def name=(val) 
          attributes[:name] = val
        end

        def code 
          attributes[:code]
        end

        def code=(val) 
          attributes[:code] = val
        end

        def source_template_uri 
          attributes[:sourceTemplateUri]
        end

        def source_template_uri=(val) 
          if val
            attributes[:sourceTemplateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:sourceTemplateUri] = nil
          end
        end

        def order 
          attributes[:order]
        end

        def order=(val) 
          attributes[:order] = val
        end

        def main 
          attributes[:main]
        end

        def main=(val) 
          attributes[:main] = val
        end

        def description 
          attributes[:description]
        end

        def description=(val) 
          attributes[:description] = val
        end        

        def locked 
          attributes[:locked]
        end

        def locked=(val) 
          attributes[:locked] = val
        end

        def lock_time 
          attributes[:lockTime]
        end

        def lock_time=(val) 
          attributes[:lockTime] = val
        end

        def lock_role_uri 
          attributes[:lockRoleUri]
        end

        def lock_role_uri=(val) 
          if val
            attributes[:lockRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:lockRoleUri] = nil
          end
        end

        def lock_access_role_uri 
          attributes[:lockAccessRoleUri]
        end

        def lock_access_role_uri=(val) 
          if val
            attributes[:lockAccessRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:lockAccessRoleUri] = nil
          end
        end

        def visible 
          attributes[:visible]
        end

        def visible=(val) 
          attributes[:visible] = val
        end

        def width 
          attributes[:width]
        end

        def width=(val) 
          attributes[:width] = val
        end

        def creation_time 
          attributes[:creationTime]
        end

        def creation_time=(val) 
          attributes[:creationTime] = val
        end

        def modification_time 
          attributes[:modificationTime]
        end

        def modification_time=(val) 
          attributes[:modificationTime] = val
        end
        
        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val) 
          attributes[:creationStamp] = val
        end

        def modification_stamp 
          attributes[:modificationStamp]
        end

        def modification_stamp=(val) 
          attributes[:modificationStamp] = val
        end
        
        def version 
          attributes[:version]
        end

        def version=(val) 
          attributes[:version] = val
        end
        
        def version_label 
          attributes[:versionLabel]
        end

        def version_label=(val) 
          attributes[:versionLabel] = val
        end
        
        def uxml_version
          attributes[:uxmlVersion]
        end

        def uxml_version=(val) 
          attributes[:uxmlVersion] = val
        end
        
        def implicit_creation 
          attributes[:implicitCreation]
        end

        def implicit_creation=(val) 
          attributes[:implicitCreation] = val
        end
        
        def entity_type_uri 
          attributes[:entityTypeUri]
        end
  
        def entity_type_uri=(val) 
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end         

      end
    end

  end
end
